
from crep.table import DataFrameContinuous


def test_constructor(get_examples):
    df_left, df_right = get_examples
    df = DataFrameContinuous(
        df_left,
        discrete_index=["id"],
        continuous_index=["t1", "t2"])

    assert hasattr(df, "discrete_index")
    assert hasattr(df, "continuous_index")
    assert hasattr(df, "admissible")

    # print(df**2)
    # assert hasattr(df**2, "discrete_index")



# Copyright 2023 Eurobios
# Licensed under the CeCILL License;
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#     https://cecill.info/
import pandas as pd
from pytest import fixture


@fixture(scope="module")
def get_examples():
    df_left = pd.read_csv("data/base_left.csv")
    df_right = pd.read_csv("data/base_right.csv")
    return df_left, df_right


@fixture(scope="module")
def get_advanced_examples():
    df_left = pd.read_csv("data/advanced_left.csv")
    df_right = pd.read_csv("data/advanced_right.csv")
    return df_left, df_right



from pandas import DataFrame
from crep import tools


from typing import Any


class DataFrameContinuous(DataFrame):

    def __init__(
            self, *args,
            discrete_index,
            continuous_index: [Any, Any],
            **kwargs):
        super().__init__(*args, **kwargs)
        self.__discrete_index = discrete_index
        self.__continuous_index = continuous_index
        self.__checks()

    def __checks(self):
        if len(self.__continuous_index) != 2:
            raise ValueError("the constructor must have "
                             "2 continuous index")
        for i in [*self.__continuous_index, *self.__discrete_index]:
            if i not in self.columns:
                raise ValueError(f"{i} must be in columns")

    @property
    def discrete_index(self):
        return self.__discrete_index

    @property
    def continuous_index(self):
        return self.__continuous_index

    @property
    def admissible(self):
        return tools.admissible_dataframe(
            self,
            self.__discrete_index,
            self.__continuous_index)
